# Contributing

## Raising an GitHub issue

Please use the provided templates for raising a feature request or defect against this project.

## Opening a pull request

Please begin by forking this repository and creating a branch from master named after the following conventions:

- `feature/<feature-name>` for a new feature
- `bugfix/<bug-name>` for a bug fix

Follow [these instructions](https://github.com/jacksmith15/statham-schema#development) to set up a development environment and run tests.

Once you are happy with you changes and tests are passing, please add an entry to `CHANGELOG.md` under [Unreleased]. Read the introduction to this file to understand its usage.

You can then open a Pull Request targeting `master`. Please ensure you follow the checklist items in the Pull Request template. The maintainer will review and likely provide feedback.

